==> sparkling-water-ml_2.11-3.34.0.4-1-2.2-sources.jar: ai/h2o/sparkling/ml/params/HasUserY.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ai.h2o.sparkling.ml.params

import ai.h2o.sparkling.H2OFrame
import org.apache.spark.sql.DataFrame

trait HasUserY extends H2OAlgoParamsBase with HasDataFrameSerializer {

  private val userY = new NullableDataFrameParam(this, "userY", "User-specified initial matrix Y.")

  setDefault(userY -> null)

  def getUserY(): DataFrame = $(userY)

  def setUserY(value: DataFrame): this.type = set(userY, value)

  private[sparkling] def getUserYParam(trainingFrame: H2OFrame): Map[String, Any] = {
    Map("user_y" -> convertDataFrameToH2OFrameKey(getUserY()))
  }

  override private[sparkling] def getSWtoH2OParamNameMap(): Map[String, String] = {
    super.getSWtoH2OParamNameMap() ++ Map("userY" -> "user_y")
  }
}

==> sparkling-water-ml_2.12-3.32.0.1-2-3.0-sources.jar: ai/h2o/sparkling/ml/params/HasUserY.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ai.h2o.sparkling.ml.params

import ai.h2o.sparkling.H2OFrame
import org.apache.spark.sql.DataFrame

trait HasUserY extends H2OAlgoParamsBase {
  private val userY = new NullableDataFrameParam(this, "userY", "User-specified initial matrix Y.")

  setDefault(userY -> null)

  def getUserY(): DataFrame = $(userY)

  def setUserY(value: DataFrame): this.type = set(userY, value)

  override private[sparkling] def getH2OAlgorithmParams(trainingFrame: H2OFrame): Map[String, Any] = {
    super.getH2OAlgorithmParams(trainingFrame) ++ Map("user_y" -> convertDataFrameToH2OFrameKey(getUserY()))
  }

  override private[sparkling] def getSWtoH2OParamNameMap(): Map[String, String] = {
    super.getSWtoH2OParamNameMap() ++ Map("userY" -> "user_y")
  }
}
